==> xld-helm-plugin-23.3.2.jar: helm/planning/plan_install.py <==
#
# Copyright (c) 2021. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of Digital.ai, Inc. and its affiliates, subsidiaries, and licensors.
#
import yaml
from helm.helmrunner import HelmConvertToTemplate
from helm.yaml.dumper import yaml_safe_dump

from java.io import ByteArrayInputStream
from java.lang import String
from java.lang import RuntimeException

if deployed.type == "helm.K8SRelease":
    container = deployed.container.container
elif deployed.type == "helm.K8SReleaseWithNamespace":
    container = deployed.container

if not container.helmClient:
    raise  Exception("Please Check if Helm Client is added in kubernetes/openshift CI.")

context.addStepWithCheckpoint(steps.jython(
    description="Install the Helm {0} release on {1} namespace".format(deployed.name, container.name),
    order=60,
    script="helm/install.py",
    jython_context={"deployed": deployed,'helmclient': container.helmClient,'cluster': container},
    preview_script="helm/preview_install.py"
), delta)

if "stitch" in dir():
    response = HelmConvertToTemplate(container.helmClient, container).execute(deployed)
    chartYaml = response['response']

    data_to_validate = list(yaml.load_all(chartYaml))
    context_to_validate = {"format": "yaml", "invocationName": deployed.name}

    for yaml_content in data_to_validate:
        try:
            context.getArtifactTransformer("stitchEngine").validate(ByteArrayInputStream(String(yaml_safe_dump(yaml_content)).getBytes()), context_to_validate)
        except RuntimeException as e:
            raise Exception("-------- Stitch Validation exception ---------- {}".format(e.getMessage()))

==> xld-helm-plugin-23.3.4.jar: helm/planning/plan_install.py <==
#
# Copyright (c) 2021. All rights reserved.
#
# This software and all trademarks, trade names, and logos included herein are the property of Digital.ai, Inc. and its affiliates, subsidiaries, and licensors.
#
import yaml
from helm.helmrunner import HelmConvertToTemplate
from helm.yaml.dumper import yaml_safe_dump

from java.io import ByteArrayInputStream
from java.lang import String
from java.lang import RuntimeException

if deployed.type in ["helm.K8SRelease", "helm.OpenshiftRelease"]:
    container = deployed.container.container
elif deployed.type == "helm.K8SReleaseWithNamespace":
    container = deployed.container

if not container.helmClient:
    raise  Exception("Please Check if Helm Client is added in kubernetes/openshift CI.")

context.addStepWithCheckpoint(steps.jython(
    description="Install the Helm {0} release on {1} namespace".format(deployed.name, container.name),
    order=60,
    script="helm/install.py",
    jython_context={"deployed": deployed,'helmclient': container.helmClient,'cluster': container},
    preview_script="helm/preview_install.py"
), delta)

if "stitch" in dir():
    response = HelmConvertToTemplate(container.helmClient, container).execute(deployed)
    chartYaml = response['response']

    data_to_validate = list(yaml.load_all(chartYaml))
    context_to_validate = {"format": "yaml", "invocationName": deployed.name}

    for yaml_content in data_to_validate:
        try:
            if yaml_content:
                context.getArtifactTransformer("stitchEngine").validate(ByteArrayInputStream(String(yaml_safe_dump(yaml_content)).getBytes()), context_to_validate)
        except RuntimeException as e:
            raise Exception("-------- Stitch Validation exception ---------- {}".format(e.getMessage()))
